%define         _disable_ld_no_undefined 0

%define         major                    1
%define         vtmajor                  0
%define         mpimajor                 1
%define         openmajor                4
%define         libname                  %mklibname %{name} %{major}
%define         develname                %mklibname %{name} -d
%define         staticdevelname          %mklibname %{name} -s -d

Summary:        An implementation of the Message Passing Interface
Name:           openmpi
Version:        1.6.5
Release:        %mkrel 2
License:        BSD
Group:          Development/Other

URL:            http://www.open-mpi.org
Source0:        http://www.open-mpi.org/software/ompi/v1.6/downloads/openmpi-%{version}.tar.bz2
Patch0:         ompi_autogen_sh.patch
Patch1:         arm_detection.diff

BuildRequires:  bison
BuildRequires:  flex
BuildRequires:  gawk
BuildRequires:  pkgconfig
BuildRequires:  gcc-gfortran
%ifarch %ix86 x86_64
BuildRequires:  java-openjdk
BuildRequires:  quadmath-devel
%endif
BuildRequires:  gcc-c++
BuildRequires:  binutils-devel
BuildRequires:  libibverbs-devel
BuildRequires:  libgomp-devel
BuildRequires:  torque-devel >= 2.3.7
BuildRequires:  zlib-devel
BuildRequires:  hwloc-devel
BuildRequires:  hwloc
BuildRequires:  autoconf

Requires:       %{libname} = %{version}-%{release}
Suggests:       %{develname} = %{version}-%{release}

Conflicts:      mpich
Conflicts:      mpich2
Conflicts:      lam


%description
The Open MPI Project is an open source MPI-2 implementation that is
developed and maintained by a consortium of academic, research, and
industry partners. OpenMPI is therefore able to combine the expertise,
technologies, and resources from all across the High Performance
Computing community in order to build the best MPI library
available. OpenMPI offers advantages for system and software vendors,
application developers and computer science researchers. This package
contains all of the tools necessary to compile, link, and run OpenMPI
jobs.



%package -n %{libname}
Summary:        Shared libraries for OpenMPI
Group:          Development/Other
#over necessary: Requires: {name} = {version}-{release}
Provides:       lib%{name} = %{version}-%{release}
Obsoletes:      %{_lib}openmpi0 <= 1.5

%description -n %{libname}
%{summary}.



%package -n %{develname}
Summary:        Development files for OpenMPI
Group:          Development/Other
Requires:       %{libname} = %{version}-%{release}
#was Requires
Suggests:       %{name} = %{version}-%{release}
Requires:       gcc-gfortran 
Requires:       gcc-c++
Provides:       lib%{name}-devel  = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}
Conflicts:      lam-devel
Conflicts:      mpich1-devel
Conflicts:      mpich2-devel

%description -n %{develname}
%{summary}.



%package -n %{staticdevelname}
Summary:        Static Development files for OpenMPI
Group:          Development/Other
Requires:       %{libname} = %{version}-%{release}
Requires:       gcc-gfortran 
Requires:       gcc-c++
Provides:       lib%{name}-static-devel  = %{version}-%{release}
Provides:       %{name}-static-devel = %{version}-%{release}
Conflicts:      lam-devel
Conflicts:      mpich1-devel
Conflicts:      mpich2-devel

%description -n %{staticdevelname}
%{summary}.



%prep
%setup -q -n %{name}-%{version}
%apply_patches
./autogen.sh

%build
%configure2_5x --enable-shared --enable-static \
               --enable-mpi-thread-multiple \
               --with-threads=posix \
               --with-tm \
               --with-hwloc=%{_prefix}

%make


%install
%makeinstall_std

%__rm -rf %{buildroot}%{_sysconfdir}/openmpi-totalview.tcl
%__rm -rf %{buildroot}%{_datadir}/libtool
%__rm -f %{buildroot}%{_datadir}/config.log
%__rm -f %{buildroot}%{_datadir}/omp.h

find %{buildroot}%{_libdir} -name *.la -delete



%files
%doc README LICENSE NEWS AUTHORS
%config(noreplace) %{_sysconfdir}/*
%{_bindir}/mpirun
%{_bindir}/mpiexec
%{_bindir}/orted
%{_bindir}/orte-*
%{_bindir}/orte_*
%{_bindir}/orterun
%{_bindir}/ompi-*
%{_bindir}/otf*
%{_datadir}/%{name}/orte*.txt
%{_datadir}/%{name}/amca*
%{_datadir}/%{name}/*.ini
%{_datadir}/%{name}/*.supp
%{_datadir}/%{name}/help*
%{_mandir}/man1/mpirun*
%{_mandir}/man1/mpiexec*
%{_mandir}/man1/orte*
%{_mandir}/man1/ompi-*
%{_mandir}/man7/*


%files -n %{libname} 
%doc %{_datadir}/%{name}/doc/COPYRIGHT-ptmalloc2.txt
%{_libdir}/*.so.%{vtmajor}*
%{_libdir}/*.so.%{major}*
%{_libdir}/*.so.%{mpimajor}*
%{_libdir}/*.so.%{openmajor}*
%{_libdir}/%{name}/*.so


%files -n %{develname}
%doc examples/
%doc %{_datadir}/vampirtrace
%{_bindir}/mpif*
%{_bindir}/mpic*
%{_bindir}/mpiC*
%{_bindir}/ortec*
%{_bindir}/orteC*
%{_bindir}/opal*
%{_bindir}/opari*
%{_bindir}/vt*
%{_bindir}/ompi_*
%{_includedir}/*
%{_libdir}/*.so
%{_libdir}/*.mod
%{_libdir}/pkgconfig/*.pc
%{_datadir}/%{name}/mpi*
%{_mandir}/man1/mpif*
%{_mandir}/man1/mpic*
%{_mandir}/man1/mpiC*
%{_mandir}/man1/ompi_*
%{_mandir}/man1/opal_wrapper*
%{_mandir}/man3/*



%files -n %{staticdevelname}
%{_libdir}/*.a
%{_libdir}/%{name}/*.a


%changelog
* Sat Oct 19 2013 umeabot <umeabot> 1.6.5-2.mga4
+ Revision: 529949
- Mageia 4 Mass Rebuild

* Mon Jul 15 2013 eatdirt <eatdirt> 1.6.5-1.mga4
+ Revision: 454402
- Upgrade to version 1.6.5 (stable release)

* Mon May 27 2013 eatdirt <eatdirt> 1.6.4-2.mga4
+ Revision: 428975
- Rebuilt for latest hwloc

* Thu Feb 28 2013 rtp <rtp> 1.6.4-1.mga3
+ Revision: 400694
- update to 1.6.4
- merge arm fixes from Debian

* Sun Jan 13 2013 umeabot <umeabot> 1.6.3-3.mga3
+ Revision: 362051
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Tue Jan 08 2013 eatdirt <eatdirt> 1.6.3-2.mga3
+ Revision: 343238
- Rebuild for new hwloc

* Sat Nov 03 2012 eatdirt <eatdirt> 1.6.3-1.mga3
+ Revision: 312732
- Upgrading to version 1.6.3

* Sat Sep 01 2012 eatdirt <eatdirt> 1.6.1-3.mga3
+ Revision: 287072
- Rebuild for hwloc library

* Sat Aug 25 2012 eatdirt <eatdirt> 1.6.1-2.mga3
+ Revision: 283838
- Rebuild for torque 2.5.12, weakening deps

* Thu Aug 23 2012 eatdirt <eatdirt> 1.6.1-1.mga3
+ Revision: 283302
- Upgrade to version 1.6.1

* Sun Jun 17 2012 eatdirt <eatdirt> 1.6-3.mga3
+ Revision: 261190
- Add upstream patch to fix wrong path to default hostfile

* Sat Jun 16 2012 eatdirt <eatdirt> 1.6-2.mga3
+ Revision: 261000
- Moving static devel files into new sub-package. Adding missing Obsoletes.

* Thu Jun 14 2012 eatdirt <eatdirt> 1.6-1.mga3
+ Revision: 260405
- Upgrade to latest stable version 1.6

* Wed Mar 07 2012 eatdirt <eatdirt> 1.4.5-2.mga2
+ Revision: 221247
- Add missing Requires (bug 2787, also applicable to Cauldron)
- Clean files repartition in between -devel and non-devel packages

* Wed Feb 22 2012 eatdirt <eatdirt> 1.4.5-1.mga2
+ Revision: 212208
- Upgrade to latest stable (1.4.5)

* Fri Jan 13 2012 eatdirt <eatdirt> 1.4.4-1.mga2
+ Revision: 195637
- Upgrade to latest stable (1.4.4)
  Specfile cleaned and ".la" files removed

* Tue Jun 28 2011 ahmad <ahmad> 1.4.3-2.mga2
+ Revision: 115348
- Drop the buildroot declaration
- Drop old/unneeded scriptlets
- imported package openmpi


* Fri Nov 26 2010 Götz Waschk <waschk@mandriva.org> 1.4.3-1mdv2011.0
+ Revision: 601501
- new version
- fix name of the library package

* Tue Jul 13 2010 Lev Givon <lev@mandriva.org> 1.4.2-1mdv2011.0
+ Revision: 552955
- Update to 1.4.2.
- Remove openmpi-1.4 tarball.

* Tue Feb 09 2010 Antoine Ginies <aginies@mandriva.com> 1.4.1-1mdv2010.1
+ Revision: 502743
- lacsi01.ps no more available
- release 1.4.1

* Thu Dec 10 2009 Funda Wang <fwang@mandriva.org> 1.4-1mdv2010.1
+ Revision: 476108
- new version 1.4

* Wed Dec 02 2009 Funda Wang <fwang@mandriva.org> 1.3.4-1mdv2010.1
+ Revision: 472481
- new version 1.3.4

* Thu Jul 23 2009 Per Øyvind Karlsen <peroyvind@mandriva.org> 1.3.3-2mdv2010.0
+ Revision: 398758
- rebuild against torque 2.3.7
- ditch INSTALL from installed files, remove redundant 'LICENSE' from list

* Wed Jul 22 2009 Per Øyvind Karlsen <peroyvind@mandriva.org> 1.3.3-1mdv2010.0
+ Revision: 398705
- new release: 1.3.3

* Wed Jul 01 2009 Lev Givon <lev@mandriva.org> 1.3.2-1mdv2010.0
+ Revision: 391293
- Update to 1.3.2.
  Fix format string compilation errors.

  + Giuseppe Ghibò <ghibo@mandriva.com>
    - Remove papi-devel from BuildRequires as requires PAPI 3.6 from http://icl.cs.utk.edu/papi/.
    - Add missed flex, bison, openmp and zlib-devel to BuildRequires.
    - Replace libnumactl-devel with numactl-devel in BuildRequires.
    - Use libnumactl-devel >= 2.0.2 in BuildRequires (otherwise it's not detected correctly).
    - Update to release 1.3.1.
    - Add binutils-devel, libibverbs-devel, libnumactl-devel, papi-devel to BuildRequires.
    - /etc/* files marked as %%config(noreplace).

* Thu Oct 23 2008 Lev Givon <lev@mandriva.org> 1.2.8-1mdv2009.1
+ Revision: 296763
- Update to 1.2.8.
  Build against torque.

* Wed Sep 03 2008 Lev Givon <lev@mandriva.org> 1.2.7-1mdv2009.0
+ Revision: 279369
- Update to 1.2.7.

* Sun Jul 20 2008 Funda Wang <fwang@mandriva.org> 1.2.6-1mdv2009.0
+ Revision: 238856
- disable undefined linking
- New version 1.2.6

  + Pixel <pixel@mandriva.com>
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers

* Sat Jan 26 2008 Giuseppe Ghibò <ghibo@mandriva.com> 1.2.5-2mdv2008.1
+ Revision: 158330
- Enable static libraries.

* Wed Jan 09 2008 Lev Givon <lev@mandriva.org> 1.2.5-1mdv2008.1
+ Revision: 147333
- Update to 1.2.5.

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Thu Oct 25 2007 Lev Givon <lev@mandriva.org> 1.2.4-2mdv2008.1
+ Revision: 102121
- Update to adhere to new devel library naming policy.
  Obsolete old versions of libopenmpi properly.
- Update to 1.2.4.

* Thu Jul 26 2007 Lev Givon <lev@mandriva.org> 1.2.3-2mdv2008.0
+ Revision: 56047
- Make openmpi package depend on devel package; the
  mpi* utilities need the header files in /usr/include to actually
  compile anything.

* Mon Jul 02 2007 Lev Givon <lev@mandriva.org> 1.2.3-1mdv2008.0
+ Revision: 47183
- Update to 1.2.3.

* Mon May 21 2007 Lev Givon <lev@mandriva.org> 1.2.2-1mdv2008.0
+ Revision: 29465
- Update to 1.2.2.

* Thu May 10 2007 Lev Givon <lev@mandriva.org> 1.2.1-1mdv2008.0
+ Revision: 26036
- Update to 1.2.1.

* Wed Apr 18 2007 Lev Givon <lev@mandriva.org> 1.2-1mdv2008.0
+ Revision: 14311
- Update to 1.2.
  Rearrange package contents.


* Mon Feb 12 2007 Lev Givon <lev@mandriva.org> 1.1.4-1mdv2007.0
+ Revision: 119014
- Update to 1.1.4.

* Mon Jan 29 2007 Lev Givon <lev@mandriva.org> 1.1.3-2mdv2007.1
+ Revision: 115137
- Install default hostfile in location expected by orted.

* Mon Jan 29 2007 Lev Givon <lev@mandriva.org> 1.1.3-1mdv2007.1
+ Revision: 114811
- Update to 1.1.3.

* Fri Jan 26 2007 Lev Givon <lev@mandriva.org> 1.1.2-1mdv2007.1
+ Revision: 113575
- Import openmpi

* Thu Jan 25 2007 Lev Givon <lev@mandriva.org> 1.1.2-1mdv2007.0
- Package for Mandriva.

